<?php

/* A plugin to use WP-reCAPTCHA in Contact Form 7.
 * This class needs WP-reCAPTCHA and Contact Form 7 plugin installed and activated.
 * http://wordpress.org/extend/plugins/wp-recaptcha/
 * http://wordpress.org/extend/plugins/contact-form-7/
 */



require_once('WPASDPlugin.class.php');

	//add_filter( 'cf7recaptcha_validate_recaptcha', 'cf7recaptcha_validation_filter', 10, 2 );


if (!class_exists('CF7reCAPTCHA')) {

    class CF7reCAPTCHA extends WPASDPlugin {
	
    
	// member variables
	private $is_useable;
	
	
	// php4 Constructor
	function CF7reCAPTCHA($options_name) {
	    
	    $args = func_get_args();
	    call_user_func_array(array(&$this, "__construct"), $args);
	}
	
	
	// php5 Constructor
	function __construct($options_name) {
	    parent::__construct($options_name);
	    
	}
	
	
	function pre_init() {
	
	    $this->register_default_options();
	    
	    // require the libraries
	    $this->require_library();
	    
	}
	
	function post_init() {
	
	    // register CF7 hooks
	    $this->register_cf7();
	    
	}
	
	// set the default options
	function register_default_options() {
	
	    if ($this->options)
		return;
		
	    $default_options = array();
	    
	    // example
	    // $default_options['option_name'] = 'value';
	    
	    
	    // add the options based on the environment
	    WPASDPlugin::add_options($this->options_name, $default_options);
	}
	
	function require_library() {
	    
	}
	
	function register_actions() {
	
	    add_action( 'admin_notices', array(&$this, 'admin_notice') );
	    
	    
	    if ($this->useable()) {
	
		add_action( 'admin_init', array(&$this, 'tag_generator_recaptcha'), 46 );
	    
	    }
	
	}
	
	
	function register_filters() {
	
	    if ( $this->useable() ) {
	    
		add_filter( 'wpcf7_validate_recaptcha', array(&$this, 'recaptcha_validation_filter'), 10, 2 );
		
		add_filter( 'wpcf7_ajax_json_echo', array(&$this, 'ajax_json_echo_filter') );
		
	    }

		
	}
	
	function register_cf7() {
	
	    // CF7 Shortcode Handler
	    if (function_exists('wpcf7_add_shortcode') && $this->useable() ) {
	    
		wpcf7_add_shortcode( 'recaptcha', array(&$this, 'shortcode_handler'), true );	
		
	    }
	    
		
	}
	
	
	function useable() {
	    if (!isset($this->is_useable)) {
		$this->is_useable = $this->is_recaptcha_active() && $this->is_cf7_active();
	    }
		
	    return $this->is_useable;
	}
    
	function is_recaptcha_active() {
	
	    return in_array( 
		'wp-recaptcha/wp-recaptcha.php', 
		apply_filters( 
		    'active_plugins', 
		    get_option( 
			'active_plugins' ) ) );
	
	}
	
	function is_cf7_active() {
	    return in_array( 
		'contact-form-7/wp-contact-form-7.php', 
		apply_filters( 
		    'active_plugins', 
		    get_option( 
			'active_plugins' ) ) );
	}
	
	
	
	function ajax_json_echo_filter( $items ) {
	    if ( ! is_array( $items['onSubmit'] ) )
		$items['onSubmit'] = array();

	    $items['onSubmit'][] = 'Recaptcha.reload();';

	    return $items;
	}


	function recaptcha_validation_filter( $result, $tag ) {
	    global $recaptcha;
	    
	    $name = $tag['name'];
	    
	    if(!$this->is_multi_blog()) {
		
		$errors = new WP_Error();
		
		$recaptcha->validate_recaptcha_response($errors);
		
		$error_list = $errors->get_error_messages(null);
		
		if (!empty($error_list)) {
		
		    $result['valid'] = false;
		    
		    $error_out = "";
		    
		    foreach ($error_list as $value) {
		    
			$error_out .= $value;	
			
		    }
		    
		    $result['reason'][$name] = $error_out;
		}
		
	    } else {
	    
	        $recaptcha->validate_recaptcha_response_wpmu($result);
		
	    }
	

	    return $result;
	}
	
	
	function tag_generator_recaptcha() {
	
	    if (function_exists('wpcf7_add_tag_generator') && $this->useable()) {
		wpcf7_add_tag_generator(
		    'recaptcha',
		    __( 'reCAPTCHA', 'cf7recaptcha'),
		    'cf7recaptcha-tg-pane',
		    array(&$this, 'cf7recaptcha_tg_pane'));
	    }
	    
	}

	
	function shortcode_handler( $tag ) {
	    global $wpcf7_contact_form, $recaptcha;

	    $name = $tag['name'];

	    $use_ssl = isset( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] == 'on';


	    $html = $recaptcha->get_recaptcha_html( null, $use_ssl );

	    $validation_error = '';
	    if ( is_a( $wpcf7_contact_form, 'WPCF7_ContactForm' ) )
		$validation_error = $wpcf7_contact_form->validation_error( $name );
	
	    //$html .= '<div id="recaptcha-submit-btn-area"></div>';
	    $html .= '<span class="wpcf7-form-control-wrap ' . $name . '">' . $validation_error . '</span>';

	    return $html;
	}


	function cf7recaptcha_tg_pane( &$contact_form ) {
?>
<div id="cf7recaptcha-tg-pane" class="hidden">
<form action="">
<table>

<?php if ( ! $this->useable() ) : ?>
<tr><td colspan="2"><strong style="color: #e6255b">you need reCAPTCHA</strong><br /></td></tr>
<?php endif; ?>

<tr><td><?php echo esc_html( __( 'Name', 'cf7recaptcha' ) ); ?><br /><input type="text" name="name" class="tg-name oneline" /></td><td></td></tr>
</table>

<div class="tg-tag"><?php echo esc_html( __( "Copy this code and paste it into the form left.", 'cf7recaptcha' ) ); ?>
<br />
<input type="text" name="recaptcha" class="tag" readonly="readonly" onfocus="this.select()" />
</div>
</form>
</div>
<?php
	}	
	
	
	function wpcf7_recaptcha_admin_notice() {
	    global $plugin_page;

    	    //if ( ! isset( $plugin_page ) || 0 !== strpos( $plugin_page, WPCF7_PLUGIN_NAME ) )
	    //	return;

	    if ( ! $this->useable() ) :

?>
<div id="message" class="updated fade"><p><?php echo esc_html( __( "You are using Contact Form 7 reCAPTCHA extension. This works with the WP-reCAPTCHA plugin, but the WP-reCAPTCHA plugin is not activated.", 'cf7recaptcha' ) ); ?>
 &mdash; WP-reCAPTCHA <a href="http://wordpress.org/extend/plugins/wp-recaptcha/">http://wordpress.org/extend/plugins/wp-recaptcha/</a><p>
</div>
<?php
	    endif;
	}
    
    }

}

?>